#
# spec file for package harbor-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name harbor

Name:           harbor-cli
Version:        0.0.7
Release:        1.1
Summary:        CLI for the Harbor cloud native registry
License:        Apache-2.0
URL:            https://github.com/harbor/harbor-cli
Source:         harbor-cli-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
CLI for the Harbor cloud native registry

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
# hash will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

GO_VERSION="$(go version | cut -c 14- | cut -d' ' -f1)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/goharbor/harbor-cli/cmd/harbor/internal/version.Version=%{version} \
   -X github.com/goharbor/harbor-cli/cmd/harbor/internal/version.GitCommit=${COMMIT_HASH:0:8} \
   -X github.com/goharbor/harbor-cli/cmd/harbor/internal/version.GoVersion=${GO_VERSION} \
   -X github.com/goharbor/harbor-cli/cmd/harbor/internal/version.ReleaseChannel=edge \
   -X github.com/goharbor/harbor-cli/cmd/harbor/internal/version.BuildTime=$BUILD_DATE" \
   -o bin/%{executable_name} ./cmd/%{executable_name}/main.go

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%check

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Tue Jun 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.0.7:
  * improved error messages for login command (#488)
  * Fix: Ensure `project create cmd` asks for necessary options
    (#447)
  * Added docs for config and encryption here from website (#487)
  * fix: remove codecov on main (#486)
  * feat: Add `label` sub-cmd in `artifact` cmd (#483)
  * feat: add `project config` command (#448)
  * adds changes suggested in context command (#482)
  * removes context switch via login command (#477)
  * Fix: Update error handling in projectName retrieval for tags
    list
  * Added return for empty reponame (#452)
  * feat: fixing the pointer positioning with change in context
    (#481)
  * Update README.md to fit correct badge
  * Unit testing Coverage report (#376)
  * Adds harbor context command (#445)
  * Fix: Doc generation script for reproducibility (#465)
  * Fix user elevate (#473)
  * fix: Show Banner messsage in system info instead of json (#471)
  * Add groups to root help command (#470)
  * fix: PreviouslyLoggedIn should display context name (#466)
  * docs: update existing and missing commands.
  * docs: update table
  * docs: update icon Update README.md
  * docs: update README to enhance clarity and detail on Harbor CLI
    features and usage
* Wed May 14 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.0.6:
  * build(deps): bump github.com/charmbracelet/bubbletea from 1.3.4
    to 1.3.5 (#449)
  * Fix: Manpages Remove Dates (#451)
  * Update the list of commands in the readme file (#454)
  * Add `scanner` cmd (#396)
  * Add: Quota Command to Manage Quotas (#97)
  * build(deps): bump golang.org/x/term from 0.31.0 to 0.32.0
    (#459)
  * feat: Update info command  (#453)
  * feat: add webhook cmd (#391)
  * Refactor: Make Error logging more user friendly for `project`
    commands (#424)
  * feat: Add systemcve cli cmd (#388)
  * Fix goreleaser (#442)
  * Improve Server Input Sanitization and Credential Name
    Generation (#443)
  * Correct Artifact View arg parsing (#444)
  * build(deps): bump github.com/charmbracelet/huh from 0.6.0 to
    0.7.0 (#433)
  * fix lint (#439)
  * Add Documentation for usage of dagger (#434)
  * build(deps): bump github.com/charmbracelet/bubbles from 0.20.0
    to 0.21.0 (#432)
  * Fix: Preserve Table Alignment While Adding Status Colors (#430)
  * fix: return proper error when a directory exists instead of
    config file (#422)
  * docs: add CONTRIBUTING.md for community contributions (#405)
  * Adds Vulnerability Check workflow (#379)
  * Continuing Work from #110: add `instance` cmd (#389)
  * FIX: project delete --force (#437)
  * refactor: Config cmd description (#427)
  * Update README.md
  * Added more info how to use harbor-cli containers correctly
  * Updates incorrect config mount location (#416)
  * Artifacthub (#413)
  * feat: add metadata labels and creation timestamp for image
    builds for artifacthub.io (#412)
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.0.5:
  * build(deps): bump golang.org/x/term from 0.27.0 to 0.31.0
    (#380)
  * fix: update golangci-lint output format to use
  - -output.tab.path
  * chore: update dependencies and golangci-lint configuration
  * chore: update golangci-lint configuration and version
  * build(deps): bump github.com/spf13/cobra from 1.8.1 to 1.9.1
    (#334)
  * build(deps): bump github.com/charmbracelet/bubbletea from 1.2.4
    to 1.3.4 (#337)
  * update dagger and go versions (#409)
  * build(deps): bump github.com/spf13/viper from 1.19.0 to 1.20.1
    (#369)
  * Improve user message in proxy cache project creation without
    adding registry-id (#395)
  * Adds login with trailing slash (#382)
  * Signed-off-by: scraly <scraly@gmail.com> (#402)
  * fix error loggin in project-list (#404)
  * feat: replace random widths with standard custom widths (#403)
  * Continuing Work from #324: add `projectID` flag to `project
    delete` cmd (#371)
  * Update golang and dagger (#408)
  * build(deps): bump github.com/charmbracelet/lipgloss from 1.0.0
    to 1.1.0 (#353)
  * Continuing Work from #129: add `immutable` cmd (#374)
  * Added environment keyring provider that takes priority over
    fallback file based keyring provider. This enables containres
    to store the encryption key more safely as env var or as k8s
    secret in k8s pods (#387)
  * Add FileKeyring as fallback for secure key storage (#385)
  * feat: Remove month from autogenerated man-docs (#370)
  * feat: Enhance `user list` cmd to fetch all users by default via
    paginated API calls (#378)
* Tue Apr  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.0.4:
  * 267 rework cherry pick (#372)
  * Added logrus timestamp formatter to cli command (#351)
  * remove unwanted changes.patch file (#317)
  * add check for page-size (#345)
  * better authorizaion (#357)
  * fix project search issue (#359)
  * default of project list as all projects (#360)
  * feat: Remove date and autogenerated line from man docs (#361)
  * gen docs for changed files (#363)
  * feat: Add `status` command (#348)
  * table doesn't get printed twice (#347)
  * move dagger to .dagger (#344)
  * project create cmd fix (#307)
  * enforce exact argument count for cmds (#302)
  * feat: Improve Performance of ` delete` Command with Concurrency
    (#80)
  * parser-fix (#299)
  * docs: reposition the FOSSA badge (#339)
  * Add license scan report and status (#338)
  * fix release issue (#335)
* Wed Feb 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.0.3:
  * Fix: Release & Publish Workflows (#313)
  * Configure Linter & Improve Workflow (#294)
  * Added the missing options in some commands and refactored some
    commands. (#77)
  * docs: update README to include directory change after cloning
    (#303)
  * 270 add ldflags to dagger (#273)
  * chore: move the ping command to handler (#285)
  * Add MAN PAGES Documentation script (#75)
  * feature: Support YAML output for newly added commands (#268)
  * build(deps): bump github.com/charmbracelet/huh from 0.5.2 to
    0.6.0 (#217)
  * feat: modified registy update command (#88)
  * Add: label commands (#95)
  * bug: fix push-latest-images and publish-release (#279)
* Thu May  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package harbor-cli: official CLI for the Harbor cloud native
  registry
